@@ -1,5 +1,5 @@
 package Bolts::Meta::Class::Trait::Locator;
-$Bolts::Meta::Class::Trait::Locator::VERSION = '0.142650';
+$Bolts::Meta::Class::Trait::Locator::VERSION = '0.142860';
 # ABSTRACT: Metaclass role for objects that have a meta locator
 
 use Moose::Role;
@@ -11,13 +11,20 @@ has locator => (
     is          => 'rw',
     does        => 'Bolts::Role::Locator',
     lazy_build  => 1,
-    handles     => 'Bolts::Role::Locator',
 );
 
 sub _build_locator {
     $Bolts::GLOBAL_FALLBACK_META_LOCATOR->new;
 }
 
+
+sub acquire     { shift->locator->acquire(@_) }
+sub acquire_all { shift->locator->acquire_all(@_) }
+sub resolve     { shift->locator->resolve(@_) }
+sub get         { shift->locator->get(@_) }
+
+with 'Bolts::Role::Locator';
+
 1;
 
 __END__
@@ -32,12 +39,22 @@ Bolts::Meta::Class::Trait::Locator - Metaclass role for objects that have a meta
 
 =head1 VERSION
 
-version 0.142650
+version 0.142860
 
 =head1 DESCRIPTION
 
 This is another handy feature for use when constructing and managing a bag of artifacts. It provides a meta locator to the class for looking up standard Bolts objects like blueprints, scopes, injectors, inferrers, etc.
 
+=head1 ROLES
+
+=over
+
+=item *
+
+L<Bolts::Role::Locator>
+
+=back
+
 =head1 ATTRIBUTES
 
 =head2 locator
@@ -46,6 +63,22 @@ This returns an implementation of L<Bolts::Role::Locator> containing the needed
 
 Defaults to a new object from L<Bolts/$Bolts::GLOBAL_FALLBACK_META_LOCATOR>, which defaults to L<Bolts::Meta::Locator>.
 
+=head2 acquire
+
+Delegated to the C<acquire> method of L</locator>.
+
+=head2 acquire_all
+
+Delegated to the C<acquire_all> method of L</locator>.
+
+=head2 resolve
+
+Delegated to the C<resolve> method of L</locator>.
+
+=head2 get
+
+Delegated to the C<get> method of L</locator>.
+
 =head1 AUTHOR
 
 Andrew Sterling Hanenkamp <hanenkamp@cpan.org>
